@@ -1,6 +1,6 @@
 from .bbox import *  # noqa: F401, F403
 from .evaluation import *  # noqa: F401, F403
 from .hooks import *  # noqa: F401, F403
-from .lr import *  # noqa: F401, F403
 from .optimizer import *  # noqa: F401, F403
 from .runner import *  # noqa: F401, F403
+from .scheduler import *  # noqa: F401, F403
