@@ -39,12 +39,17 @@ def confusion_matrix(y_pred, y_real, normalize=None):
 
     label_set = np.unique(np.concatenate((y_pred, y_real)))
     num_labels = len(label_set)
-    label_map = {label: i for i, label in enumerate(label_set)}
-    confusion_mat = np.zeros((num_labels, num_labels), dtype=np.int64)
-    for rlabel, plabel in zip(y_real, y_pred):
-        index_real = label_map[rlabel]
-        index_pred = label_map[plabel]
-        confusion_mat[index_real][index_pred] += 1
+    max_label = label_set[-1]
+    label_map = np.zeros(max_label + 1, dtype=np.int64)
+    for i, label in enumerate(label_set):
+        label_map[label] = i
+
+    y_pred_mapped = label_map[y_pred]
+    y_real_mapped = label_map[y_real]
+
+    confusion_mat = np.bincount(
+        num_labels * y_real_mapped + y_pred_mapped,
+        minlength=num_labels**2).reshape(num_labels, num_labels)
 
     with np.errstate(all='ignore'):
         if normalize == 'true':
@@ -82,6 +87,45 @@ def mean_class_accuracy(scores, labels):
     return mean_class_acc
 
 
+def top_k_classes(scores, labels, k=10, mode='accurate'):
+    """Calculate the most K accurate (inaccurate) classes.
+
+    Given the prediction scores, ground truth label and top-k value,
+    compute the top K accurate (inaccurate) classes.
+
+    Args:
+        scores (list[np.ndarray]): Prediction scores for each class.
+        labels (list[int] | np.ndarray): Ground truth labels.
+        k (int): Top-k values. Default: 10.
+        mode (str): Comparison mode for Top-k. Options are 'accurate'
+            and 'inaccurate'. Default: 'accurate'.
+
+    Return:
+        list: List of sorted (from high accuracy to low accuracy for
+            'accurate' mode, and from low accuracy to high accuracy for
+            inaccurate mode) top K classes in format of (label_id,
+            acc_ratio).
+    """
+    assert mode in ['accurate', 'inaccurate']
+    pred = np.argmax(scores, axis=1)
+    cf_mat = confusion_matrix(pred, labels).astype(float)
+
+    cls_cnt = cf_mat.sum(axis=1)
+    cls_hit = np.diag(cf_mat)
+    hit_ratio = np.array(
+        [hit / cnt if cnt else 0.0 for cnt, hit in zip(cls_cnt, cls_hit)])
+
+    if mode == 'accurate':
+        max_index = np.argsort(hit_ratio)[-k:][::-1]
+        max_value = hit_ratio[max_index]
+        results = list(zip(max_index, max_value))
+    else:
+        min_index = np.argsort(hit_ratio)[:k]
+        min_value = hit_ratio[min_index]
+        results = list(zip(min_index, min_value))
+    return results
+
+
 def top_k_accuracy(scores, labels, topk=(1, )):
     """Calculate top k accuracy score.
 
@@ -104,22 +148,52 @@ def top_k_accuracy(scores, labels, topk=(1, )):
     return res
 
 
+def mmit_mean_average_precision(scores, labels):
+    """Mean average precision for multi-label recognition. Used for reporting
+    MMIT style mAP on Multi-Moments in Times. The difference is that this
+    method calculates average-precision for each sample and averages them among
+    samples.
+
+    Args:
+        scores (list[np.ndarray]): Prediction scores of different classes for
+            each sample.
+        labels (list[np.ndarray]): Ground truth many-hot vector for each
+            sample.
+
+    Returns:
+        np.float: The MMIT style mean average precision.
+    """
+    results = []
+    for score, label in zip(scores, labels):
+        precision, recall, _ = binary_precision_recall_curve(score, label)
+        ap = -np.sum(np.diff(recall) * np.array(precision)[:-1])
+        results.append(ap)
+    return np.mean(results)
+
+
 def mean_average_precision(scores, labels):
     """Mean average precision for multi-label recognition.
 
     Args:
-        scores (list[np.ndarray]): Prediction scores for each class.
-        labels (list[np.ndarray]): Ground truth many-hot vector.
+        scores (list[np.ndarray]): Prediction scores of different classes for
+            each sample.
+        labels (list[np.ndarray]): Ground truth many-hot vector for each
+            sample.
 
     Returns:
         np.float: The mean average precision.
     """
     results = []
-    for i in range(len(scores)):
-        precision, recall, _ = binary_precision_recall_curve(
-            scores[i], labels[i])
+    scores = np.stack(scores).T
+    labels = np.stack(labels).T
+
+    for score, label in zip(scores, labels):
+        precision, recall, _ = binary_precision_recall_curve(score, label)
         ap = -np.sum(np.diff(recall) * np.array(precision)[:-1])
         results.append(ap)
+    results = [x for x in results if not np.isnan(x)]
+    if results == []:
+        return np.nan
     return np.mean(results)
 
 
@@ -167,27 +241,38 @@ def binary_precision_recall_curve(y_score, y_true):
     return np.r_[precision[sl], 1], np.r_[recall[sl], 0], thresholds[sl]
 
 
-def pairwise_temporal_iou(candidate_segments, target_segments):
+def pairwise_temporal_iou(candidate_segments,
+                          target_segments,
+                          calculate_overlap_self=False):
     """Compute intersection over union between segments.
 
     Args:
         candidate_segments (np.ndarray): 1-dim/2-dim array in format
-            [init, end]/[m x 2:=[init, end]].
+            ``[init, end]/[m x 2:=[init, end]]``.
         target_segments (np.ndarray): 2-dim array in format
-            [n x 2:=[init, end]].
+            ``[n x 2:=[init, end]]``.
+        calculate_overlap_self (bool): Whether to calculate overlap_self
+            (union / candidate_length) or not. Default: False.
 
     Returns:
         t_iou (np.ndarray): 1-dim array [n] /
             2-dim array [n x m] with IoU ratio.
+        t_overlap_self (np.ndarray, optional): 1-dim array [n] /
+            2-dim array [n x m] with overlap_self, returns when
+            calculate_overlap_self is True.
     """
-    if target_segments.ndim != 2 or candidate_segments.ndim not in [1, 2]:
+    candidate_segments_ndim = candidate_segments.ndim
+    if target_segments.ndim != 2 or candidate_segments_ndim not in [1, 2]:
         raise ValueError('Dimension of arguments is incorrect')
 
-    if candidate_segments.ndim == 1:
+    if candidate_segments_ndim == 1:
         candidate_segments = candidate_segments[np.newaxis, :]
 
     n, m = target_segments.shape[0], candidate_segments.shape[0]
     t_iou = np.empty((n, m), dtype=np.float32)
+    if calculate_overlap_self:
+        t_overlap_self = np.empty((n, m), dtype=np.float32)
+
     for i in range(m):
         candidate_segment = candidate_segments[i, :]
         tt1 = np.maximum(candidate_segment[0], target_segments[:, 0])
@@ -201,6 +286,17 @@ def pairwise_temporal_iou(candidate_segments, target_segments):
         # Compute overlap as the ratio of the intersection
         # over union of two segments.
         t_iou[:, i] = (segments_intersection.astype(float) / segments_union)
+        if calculate_overlap_self:
+            candidate_length = candidate_segment[1] - candidate_segment[0]
+            t_overlap_self[:, i] = (
+                segments_intersection.astype(float) / candidate_length)
+
+    if candidate_segments_ndim == 1:
+        t_iou = np.squeeze(t_iou, axis=1)
+    if calculate_overlap_self:
+        if candidate_segments_ndim == 1:
+            t_overlap_self = np.squeeze(t_overlap_self, axis=1)
+        return t_iou, t_overlap_self
 
     return t_iou
 
@@ -222,7 +318,7 @@ def average_recall_at_avg_proposals(ground_truth,
         max_avg_proposals (int | None): Max number of proposals for one video.
             Default: None.
         temporal_iou_thresholds (np.ndarray): 1D array with temporal_iou
-            thresholds. Default: np.linspace(0.5, 0.95, 10).
+            thresholds. Default: ``np.linspace(0.5, 0.95, 10)``.
 
     Returns:
         tuple([np.ndarray, np.ndarray, np.ndarray, float]):
@@ -233,7 +329,7 @@ def average_recall_at_avg_proposals(ground_truth,
             over a list of temporal_iou threshold (1D array). This is
             equivalent to ``recall.mean(axis=0)``. The ``proposals_per_video``
             is the average number of proposals per video. The auc is the area
-            under AR@AN curve.
+            under ``AR@AN`` curve.
     """
 
     total_num_videos = len(ground_truth)
@@ -342,7 +438,7 @@ def get_weighted_score(score_list, coeff_list):
             n(number of predictions) X num_samples X num_classes
         coeff_list (list[float]): List of coefficients, with shape n.
 
-    Return:
+    Returns:
         list[np.ndarray]: List of weighted scores.
     """
     assert len(score_list) == len(coeff_list)
@@ -393,12 +489,12 @@ def average_precision_at_temporal_iou(ground_truth,
     Args:
         ground_truth (dict): Dict containing the ground truth instances.
             Key: 'video_id'
-            Value (np.ndarry): 1D array of 't-start' and 't-end'.
-        proposals (np.ndarray): 2D array containing the information of proposal
-            instances, including 'video_id', 'class_id', 't-start', 't-end' and
-            'score'.
+            Value (np.ndarray): 1D array of 't-start' and 't-end'.
+        prediction (np.ndarray): 2D array containing the information of
+            proposal instances, including 'video_id', 'class_id', 't-start',
+            't-end' and 'score'.
         temporal_iou_thresholds (np.ndarray): 1D array with temporal_iou
-            thresholds. Default: np.linspace(0.5, 0.95, 10).
+            thresholds. Default: ``np.linspace(0.5, 0.95, 10)``.
 
     Returns:
         np.ndarray: 1D array of average precision score.
@@ -430,7 +526,7 @@ def average_precision_at_temporal_iou(ground_truth,
     for idx, this_pred in enumerate(prediction):
 
         # Check if there is at least one ground truth in the video.
-        if (this_pred[0] in ground_truth):
+        if this_pred[0] in ground_truth:
             this_gt = np.array(ground_truth[this_pred[0]], dtype=float)
         else:
             fp[:, idx] = 1
