@@ -8,7 +8,7 @@ from .blending_utils import (BaseMiniBatchBlending, CutmixBlending,
                              MixupBlending)
 from .builder import (BLENDINGS, DATASETS, PIPELINES, build_dataloader,
                       build_dataset)
-from .dataset_wrappers import RepeatDataset
+from .dataset_wrappers import ConcatDataset, RepeatDataset
 from .hvu_dataset import HVUDataset
 from .image_dataset import ImageDataset
 from .pose_dataset import PoseDataset
@@ -23,5 +23,5 @@ __all__ = [
     'HVUDataset', 'AudioDataset', 'AudioFeatureDataset', 'ImageDataset',
     'RawVideoDataset', 'AVADataset', 'AudioVisualDataset',
     'BaseMiniBatchBlending', 'CutmixBlending', 'MixupBlending', 'DATASETS',
-    'PIPELINES', 'BLENDINGS', 'PoseDataset'
+    'PIPELINES', 'BLENDINGS', 'PoseDataset', 'ConcatDataset'
 ]
