@@ -3,7 +3,7 @@ import torch.nn as nn
 from mmcv.cnn import NonLocal3d
 from torch.nn.modules.utils import _ntuple
 
-from ..registry import BACKBONES
+from ..builder import BACKBONES
 from .resnet import ResNet
 
 
@@ -173,7 +173,7 @@ class ResNetTSM(ResNet):
             ]
         else:
             num_segment_list = [self.num_segments] * 4
-        if not num_segment_list[-1] > 0:
+        if num_segment_list[-1] <= 0:
             raise ValueError('num_segment_list[-1] must be positive')
 
         if self.shift_place == 'block':
