@@ -8,7 +8,7 @@ from mmcv.runner import load_checkpoint
 from mmcv.utils import _BatchNorm
 
 from ...utils import get_root_logger
-from ..registry import BACKBONES
+from ..builder import BACKBONES
 
 
 class SEModule(nn.Module):
