@@ -16,22 +16,56 @@ if mmdet_imported:
     @MMDET_HEADS.register_module()
     class AVARoIHead(StandardRoIHead):
 
-        def _bbox_forward(self, x, rois):
-            bbox_feat = self.bbox_roi_extractor(x, rois)
+        def _bbox_forward(self, x, rois, img_metas):
+            """Defines the computation performed to get bbox predictions.
+
+            Args:
+                x (torch.Tensor): The input tensor.
+                rois (torch.Tensor): The regions of interest.
+                img_metas (list): The meta info of images
+
+            Returns:
+                dict: bbox predictions with features and classification scores.
+            """
+            bbox_feat, global_feat = self.bbox_roi_extractor(x, rois)
+
             if self.with_shared_head:
-                bbox_feat = self.shared_head(bbox_feat)
+                bbox_feat = self.shared_head(
+                    bbox_feat,
+                    feat=global_feat,
+                    rois=rois,
+                    img_metas=img_metas)
+
             cls_score, bbox_pred = self.bbox_head(bbox_feat)
 
             bbox_results = dict(
                 cls_score=cls_score, bbox_pred=bbox_pred, bbox_feats=bbox_feat)
             return bbox_results
 
+        def _bbox_forward_train(self, x, sampling_results, gt_bboxes,
+                                gt_labels, img_metas):
+            """Run forward function and calculate loss for box head in
+            training."""
+            rois = bbox2roi([res.bboxes for res in sampling_results])
+            bbox_results = self._bbox_forward(x, rois, img_metas)
+
+            bbox_targets = self.bbox_head.get_targets(sampling_results,
+                                                      gt_bboxes, gt_labels,
+                                                      self.train_cfg)
+            loss_bbox = self.bbox_head.loss(bbox_results['cls_score'],
+                                            bbox_results['bbox_pred'], rois,
+                                            *bbox_targets)
+
+            bbox_results.update(loss_bbox=loss_bbox)
+            return bbox_results
+
         def simple_test(self,
                         x,
                         proposal_list,
                         img_metas,
                         proposals=None,
                         rescale=False):
+            """Defines the computation performed for simple testing."""
             assert self.with_bbox, 'Bbox head must be implemented.'
 
             if isinstance(x, tuple):
@@ -59,7 +93,7 @@ if mmdet_imported:
                                rescale=False):
             """Test only det bboxes without augmentation."""
             rois = bbox2roi(proposals)
-            bbox_results = self._bbox_forward(x, rois)
+            bbox_results = self._bbox_forward(x, rois, img_metas)
             cls_score = bbox_results['cls_score']
 
             img_shape = img_metas[0]['img_shape']
